==> grommet-0.2.2.tgz: package/examples/medium-app/src/js/server-profiles/ServerProfileOverview.js <==
// (C) Copyright 2014-2015 Hewlett-Packard Development Company, L.P.

var React = require('react');
var Link = require('react-router').Link;
var RestWatch = require('grommet/utils/RestWatch');
var GrommetDocument = require('grommet/components/Document');
var Header = require('grommet/components/Header');
var Section = require('grommet/components/Section');
var ResourceNotifications = require('grommet/components/index/ResourceNotifications');
var Attribute = require('grommet/components/Attribute');
var StatusIcon = require('grommet/components/icons/Status');
var Tiles = require('grommet/components/Tiles');
//var Tile = require('grommet/components/Tile');

var ServerProfileOverview = React.createClass({

  contextTypes: {
    router: React.PropTypes.func.isRequired
  },

  _onUpdate: function (result) {
    this.setState({serverProfile: result});
  },

  _getData: function () {
    this._watch = RestWatch.start(this.state.uri, null, this._onUpdate);
  },

  getInitialState: function () {
    var router = this.context.router;
    return {
      uri: router.getCurrentParams().splat,
      serverProfile: {}
    };
  },

  componentDidMount: function () {
    this._getData();
  },

  componentWillReceiveProps: function () {
    var router = this.context.router;
    var uri = router.getCurrentParams().splat;
    if (uri !== this.state.uri) {
      this.setState({uri: uri}, this._getData);
    }
  },

  componentWillUnmount: function () {
    RestWatch.stop(this._watch);
  },

  render: function () {
    var serverProfile = this.state.serverProfile;

    var serverHardwareLink;
    if (serverProfile.serverHardware) {
      serverHardwareLink = (
        <Link to="server hardware"
          param={{splat: serverProfile.serverHardware.uri}}>
          {serverProfile.serverHardware.name}
        </Link>
      );
    }
    var connections;

    return (
      <GrommetDocument flush={false}>
        <Header flush={false} small={true}>
          <span>
            <StatusIcon value={serverProfile.status} />
            {serverProfile.name}
          </span>
        </Header>

        <ResourceNotifications resourceUri={this.state.uri} />

        <Section compact={true} flush={false}>
          <Attribute label="Description">
            {serverProfile.description}
          </Attribute>
          <Attribute label="Server hardware">
            {serverHardwareLink}
          </Attribute>
          <Attribute label="Affinity">
            {serverProfile.affinity}
          </Attribute>
        </Section>

        <Section compact={true} flush={false} colorIndex="neutral-1">
          <h2>Firmware</h2>
          <Attribute label="Firmware baseline">
            {serverProfile.firmwareBaseline}
          </Attribute>
        </Section>

        <Section compact={true} flush={false} colorIndex="neutral-2">
          <h2>Connections</h2>
          <Tiles flush={false}>
            {connections}
          </Tiles>
        </Section>

      </GrommetDocument>
    );
  }
});

module.exports = ServerProfileOverview;

==> grommet-0.3.0.tgz: package/examples/medium-app/src/js/server-profiles/ServerProfileOverview.js <==
// (C) Copyright 2014-2015 Hewlett-Packard Development Company, L.P.

var React = require('react');
var Link = require('react-router').Link;
var RestWatch = require('grommet/utils/RestWatch');
var Article = require('grommet/components/Article');
var Header = require('grommet/components/Header');
var Section = require('grommet/components/Section');
var ResourceNotifications = require('grommet/components/index/ResourceNotifications');
var Attribute = require('grommet/components/Attribute');
var StatusIcon = require('grommet/components/icons/Status');
var Tiles = require('grommet/components/Tiles');
//var Tile = require('grommet/components/Tile');

var ServerProfileOverview = React.createClass({

  contextTypes: {
    router: React.PropTypes.func.isRequired
  },

  _onUpdate: function (result) {
    this.setState({serverProfile: result});
  },

  _getData: function () {
    this._watch = RestWatch.start(this.state.uri, null, this._onUpdate);
  },

  getInitialState: function () {
    var router = this.context.router;
    return {
      uri: router.getCurrentParams().splat,
      serverProfile: {}
    };
  },

  componentDidMount: function () {
    this._getData();
  },

  componentWillReceiveProps: function () {
    var router = this.context.router;
    var uri = router.getCurrentParams().splat;
    if (uri !== this.state.uri) {
      this.setState({uri: uri}, this._getData);
    }
  },

  componentWillUnmount: function () {
    RestWatch.stop(this._watch);
  },

  render: function () {
    var serverProfile = this.state.serverProfile;

    var serverHardwareLink;
    if (serverProfile.serverHardware) {
      serverHardwareLink = (
        <Link to="server hardware"
          param={{splat: serverProfile.serverHardware.uri}}>
          {serverProfile.serverHardware.name}
        </Link>
      );
    }
    var connections;

    return (
      <Article>
        <Header pad={{horizontal: 'medium'}}>
          <span>
            <StatusIcon value={serverProfile.status} />
            {serverProfile.name}
          </span>
        </Header>

        <ResourceNotifications resourceUri={this.state.uri} />

        <Section pad="medium">
          <Attribute label="Description">
            {serverProfile.description}
          </Attribute>
          <Attribute label="Server hardware">
            {serverHardwareLink}
          </Attribute>
          <Attribute label="Affinity">
            {serverProfile.affinity}
          </Attribute>
        </Section>

        <Section pad="medium" colorIndex="neutral-1">
          <h2>Firmware</h2>
          <Attribute label="Firmware baseline">
            {serverProfile.firmwareBaseline}
          </Attribute>
        </Section>

        <Section pad="medium" colorIndex="neutral-2">
          <h2>Connections</h2>
          <Tiles flush={false}>
            {connections}
          </Tiles>
        </Section>

      </Article>
    );
  }
});

module.exports = ServerProfileOverview;
